@@ -1,9 +1,7 @@
-import shlex
 from typing import List, Union
 
 from .. import util
 from ..context import Context
-from ..exceptions import InstaterError
 from . import Task
 
 
@@ -22,19 +20,12 @@ class Command(Task):
         if isinstance(command, str):
             command = [command]
 
-        self.commands = list(map(self._parse_command, command))
-        self.condition = self._parse_command(condition) if condition else None
+        self.commands = command
+        self.condition = condition
         self.condition_code = int(condition_code)
         self.become = become
         self.directory = directory
 
-    def _parse_command(self, command: str) -> List[str]:
-        cmd = shlex.split(command)
-        if not cmd:
-            raise InstaterError("No valid command specified")
-
-        return cmd
-
     def run_action(self, context: Context) -> bool:
         if self.condition:
             # TODO: only consider specific return codes as valid?
